summaryrefslogtreecommitdiffstats
path: root/libtdegames
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
commit84ace1135cac57993b72fee7105b92def1638d32 (patch)
treeb8871eb76e3db4a062731b0ce7c99c24fac119e8 /libtdegames
parent97d1732e257f8700488d7ca1660ae7eba8fc6065 (diff)
downloadtdegames-84ace1135cac57993b72fee7105b92def1638d32.tar.gz
tdegames-84ace1135cac57993b72fee7105b92def1638d32.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 97d1732e257f8700488d7ca1660ae7eba8fc6065.
Diffstat (limited to 'libtdegames')
-rwxr-xr-xlibtdegames/carddecks/convertpysols104
-rw-r--r--libtdegames/highscore/kexthighscore.cpp2
-rw-r--r--libtdegames/highscore/kexthighscore_gui.cpp10
-rw-r--r--libtdegames/highscore/kexthighscore_internal.cpp20
-rw-r--r--libtdegames/highscore/kexthighscore_item.cpp8
-rw-r--r--libtdegames/highscore/kexthighscore_item.h10
-rw-r--r--libtdegames/highscore/kexthighscore_tab.cpp8
-rw-r--r--libtdegames/highscore/khighscore.cpp18
-rw-r--r--libtdegames/highscore/khighscore.h2
-rw-r--r--libtdegames/highscore/kscoredialog.cpp42
-rw-r--r--libtdegames/kcanvasrootpixmap.cpp2
-rw-r--r--libtdegames/kcarddialog.cpp94
-rw-r--r--libtdegames/kchatbase.cpp16
-rw-r--r--libtdegames/kchatbase.h2
-rw-r--r--libtdegames/kchatdialog.cpp24
-rw-r--r--libtdegames/kgame/COMPAT2
-rw-r--r--libtdegames/kgame/DESIGN2
-rw-r--r--libtdegames/kgame/dialogs/kgameconnectdialog.cpp2
-rw-r--r--libtdegames/kgame/dialogs/kgamedebugdialog.cpp42
-rw-r--r--libtdegames/kgame/dialogs/kgamedialog.cpp2
-rw-r--r--libtdegames/kgame/dialogs/kgamedialogconfig.cpp6
-rw-r--r--libtdegames/kgame/dialogs/kgamedialogconfig.h2
-rw-r--r--libtdegames/kgame/dialogs/kgameerrordialog.cpp6
-rw-r--r--libtdegames/kgame/kgame.cpp28
-rw-r--r--libtdegames/kgame/kgame.h10
-rw-r--r--libtdegames/kgame/kgamechat.cpp6
-rw-r--r--libtdegames/kgame/kgameerror.cpp6
-rw-r--r--libtdegames/kgame/kgameproperty.h2
-rw-r--r--libtdegames/kgame/kgamepropertyhandler.cpp6
-rw-r--r--libtdegames/kgame/kmessageclient.cpp8
-rw-r--r--libtdegames/kgame/kmessageclient.h6
-rw-r--r--libtdegames/kgame/kmessageio.cpp2
-rw-r--r--libtdegames/kgame/kmessageio.h2
-rw-r--r--libtdegames/kgame/kmessageserver.h2
-rw-r--r--libtdegames/kgame/messages.txt2
-rw-r--r--libtdegames/kgamelcd.cpp8
-rw-r--r--libtdegames/kgamelcd.h2
-rw-r--r--libtdegames/kgameprogress.cpp26
-rw-r--r--libtdegames/kgameprogress.h4
39 files changed, 273 insertions, 273 deletions
diff --git a/libtdegames/carddecks/convertpysols b/libtdegames/carddecks/convertpysols
index 5ed10b25..f2434475 100755
--- a/libtdegames/carddecks/convertpysols
+++ b/libtdegames/carddecks/convertpysols
@@ -2,68 +2,68 @@
cd $1
-convert -format png -geometry "72x96" 01c.gif 1.png
-convert -format png -geometry "72x96" 01s.gif 2.png
-convert -format png -geometry "72x96" 01h.gif 3.png
-convert -format png -geometry "72x96" 01d.gif 4.png
+convert -format png -tqgeometry "72x96" 01c.gif 1.png
+convert -format png -tqgeometry "72x96" 01s.gif 2.png
+convert -format png -tqgeometry "72x96" 01h.gif 3.png
+convert -format png -tqgeometry "72x96" 01d.gif 4.png
-convert -format png -geometry "72x96" 13c.gif 5.png
-convert -format png -geometry "72x96" 13s.gif 6.png
-convert -format png -geometry "72x96" 13h.gif 7.png
-convert -format png -geometry "72x96" 13d.gif 8.png
+convert -format png -tqgeometry "72x96" 13c.gif 5.png
+convert -format png -tqgeometry "72x96" 13s.gif 6.png
+convert -format png -tqgeometry "72x96" 13h.gif 7.png
+convert -format png -tqgeometry "72x96" 13d.gif 8.png
-convert -format png -geometry "72x96" 12c.gif 9.png
-convert -format png -geometry "72x96" 12s.gif 10.png
-convert -format png -geometry "72x96" 12h.gif 11.png
-convert -format png -geometry "72x96" 12d.gif 12.png
+convert -format png -tqgeometry "72x96" 12c.gif 9.png
+convert -format png -tqgeometry "72x96" 12s.gif 10.png
+convert -format png -tqgeometry "72x96" 12h.gif 11.png
+convert -format png -tqgeometry "72x96" 12d.gif 12.png
-convert -format png -geometry "72x96" 11c.gif 13.png
-convert -format png -geometry "72x96" 11s.gif 14.png
-convert -format png -geometry "72x96" 11h.gif 15.png
-convert -format png -geometry "72x96" 11d.gif 16.png
+convert -format png -tqgeometry "72x96" 11c.gif 13.png
+convert -format png -tqgeometry "72x96" 11s.gif 14.png
+convert -format png -tqgeometry "72x96" 11h.gif 15.png
+convert -format png -tqgeometry "72x96" 11d.gif 16.png
-convert -format png -geometry "72x96" 10c.gif 17.png
-convert -format png -geometry "72x96" 10s.gif 18.png
-convert -format png -geometry "72x96" 10h.gif 19.png
-convert -format png -geometry "72x96" 10d.gif 20.png
+convert -format png -tqgeometry "72x96" 10c.gif 17.png
+convert -format png -tqgeometry "72x96" 10s.gif 18.png
+convert -format png -tqgeometry "72x96" 10h.gif 19.png
+convert -format png -tqgeometry "72x96" 10d.gif 20.png
-convert -format png -geometry "72x96" 09c.gif 21.png
-convert -format png -geometry "72x96" 09s.gif 22.png
-convert -format png -geometry "72x96" 09h.gif 23.png
-convert -format png -geometry "72x96" 09d.gif 24.png
+convert -format png -tqgeometry "72x96" 09c.gif 21.png
+convert -format png -tqgeometry "72x96" 09s.gif 22.png
+convert -format png -tqgeometry "72x96" 09h.gif 23.png
+convert -format png -tqgeometry "72x96" 09d.gif 24.png
-convert -format png -geometry "72x96" 08c.gif 25.png
-convert -format png -geometry "72x96" 08s.gif 26.png
-convert -format png -geometry "72x96" 08h.gif 27.png
-convert -format png -geometry "72x96" 08d.gif 28.png
+convert -format png -tqgeometry "72x96" 08c.gif 25.png
+convert -format png -tqgeometry "72x96" 08s.gif 26.png
+convert -format png -tqgeometry "72x96" 08h.gif 27.png
+convert -format png -tqgeometry "72x96" 08d.gif 28.png
-convert -format png -geometry "72x96" 07c.gif 29.png
-convert -format png -geometry "72x96" 07s.gif 30.png
-convert -format png -geometry "72x96" 07h.gif 31.png
-convert -format png -geometry "72x96" 07d.gif 32.png
+convert -format png -tqgeometry "72x96" 07c.gif 29.png
+convert -format png -tqgeometry "72x96" 07s.gif 30.png
+convert -format png -tqgeometry "72x96" 07h.gif 31.png
+convert -format png -tqgeometry "72x96" 07d.gif 32.png
-convert -format png -geometry "72x96" 06c.gif 33.png
-convert -format png -geometry "72x96" 06s.gif 34.png
-convert -format png -geometry "72x96" 06h.gif 35.png
-convert -format png -geometry "72x96" 06d.gif 36.png
+convert -format png -tqgeometry "72x96" 06c.gif 33.png
+convert -format png -tqgeometry "72x96" 06s.gif 34.png
+convert -format png -tqgeometry "72x96" 06h.gif 35.png
+convert -format png -tqgeometry "72x96" 06d.gif 36.png
-convert -format png -geometry "72x96" 05c.gif 37.png
-convert -format png -geometry "72x96" 05s.gif 38.png
-convert -format png -geometry "72x96" 05h.gif 39.png
-convert -format png -geometry "72x96" 05d.gif 40.png
+convert -format png -tqgeometry "72x96" 05c.gif 37.png
+convert -format png -tqgeometry "72x96" 05s.gif 38.png
+convert -format png -tqgeometry "72x96" 05h.gif 39.png
+convert -format png -tqgeometry "72x96" 05d.gif 40.png
-convert -format png -geometry "72x96" 04c.gif 41.png
-convert -format png -geometry "72x96" 04s.gif 42.png
-convert -format png -geometry "72x96" 04h.gif 43.png
-convert -format png -geometry "72x96" 04d.gif 44.png
+convert -format png -tqgeometry "72x96" 04c.gif 41.png
+convert -format png -tqgeometry "72x96" 04s.gif 42.png
+convert -format png -tqgeometry "72x96" 04h.gif 43.png
+convert -format png -tqgeometry "72x96" 04d.gif 44.png
-convert -format png -geometry "72x96" 03c.gif 45.png
-convert -format png -geometry "72x96" 03s.gif 46.png
-convert -format png -geometry "72x96" 03h.gif 47.png
-convert -format png -geometry "72x96" 03d.gif 48.png
+convert -format png -tqgeometry "72x96" 03c.gif 45.png
+convert -format png -tqgeometry "72x96" 03s.gif 46.png
+convert -format png -tqgeometry "72x96" 03h.gif 47.png
+convert -format png -tqgeometry "72x96" 03d.gif 48.png
-convert -format png -geometry "72x96" 02c.gif 49.png
-convert -format png -geometry "72x96" 02s.gif 50.png
-convert -format png -geometry "72x96" 02h.gif 51.png
-convert -format png -geometry "72x96" 02d.gif 52.png
+convert -format png -tqgeometry "72x96" 02c.gif 49.png
+convert -format png -tqgeometry "72x96" 02s.gif 50.png
+convert -format png -tqgeometry "72x96" 02h.gif 51.png
+convert -format png -tqgeometry "72x96" 02d.gif 52.png
diff --git a/libtdegames/highscore/kexthighscore.cpp b/libtdegames/highscore/kexthighscore.cpp
index 46010c41..d352a266 100644
--- a/libtdegames/highscore/kexthighscore.cpp
+++ b/libtdegames/highscore/kexthighscore.cpp
@@ -19,7 +19,7 @@
#include "kexthighscore.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <kdebug.h>
diff --git a/libtdegames/highscore/kexthighscore_gui.cpp b/libtdegames/highscore/kexthighscore_gui.cpp
index eb715273..02ea99b6 100644
--- a/libtdegames/highscore/kexthighscore_gui.cpp
+++ b/libtdegames/highscore/kexthighscore_gui.cpp
@@ -20,8 +20,8 @@
#include "kexthighscore_gui.h"
#include "kexthighscore_gui.moc"
-#include <layout.h>
-#include <textstream.h>
+#include <tqlayout.h>
+#include <tqtextstream.h>
#include <tqheader.h>
#include <tqgrid.h>
#include <tqvgroupbox.h>
@@ -92,7 +92,7 @@ void ScoresList::addLineItem(const ItemArray &items,
if (line) line->setText(k, itemText(container, index));
else {
addColumn( container.item()->label() );
- setColumnAlignment(k, container.item()->alignment());
+ setColumnAlignment(k, container.item()->tqalignment());
}
k++;
}
@@ -289,7 +289,7 @@ void LastMultipleScoresList::addLineItem(const ItemArray &si,
if (line) line->setText(i, itemText(*container, index));
else {
addColumn( container->item()->label() );
- setColumnAlignment(i, container->item()->alignment());
+ setColumnAlignment(i, container->item()->tqalignment());
}
}
}
@@ -333,7 +333,7 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
TQString label =
(i==2 ? i18n("Won Games") : container->item()->label());
addColumn(label);
- setColumnAlignment(i, container->item()->alignment());
+ setColumnAlignment(i, container->item()->tqalignment());
}
}
}
diff --git a/libtdegames/highscore/kexthighscore_internal.cpp b/libtdegames/highscore/kexthighscore_internal.cpp
index 4803909a..a679002c 100644
--- a/libtdegames/highscore/kexthighscore_internal.cpp
+++ b/libtdegames/highscore/kexthighscore_internal.cpp
@@ -24,7 +24,7 @@
#include <unistd.h>
#include <tqfile.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqdom.h>
#include <kglobal.h>
@@ -314,7 +314,7 @@ PlayerInfos::PlayerInfos()
#ifdef HIGHSCORE_DIRECTORY
if (_oldLocalPlayer) { // player already exists in local config file
// copy player data
- TQString prefix = TQString("%1_").arg(_oldLocalId+1);
+ TQString prefix = TQString("%1_").tqarg(_oldLocalId+1);
TQMap<TQString, TQString> entries =
cg.config()->entryMap("KHighscore_players");
TQMap<TQString, TQString>::const_iterator it;
@@ -378,8 +378,8 @@ TQString PlayerInfos::histoName(uint i) const
const TQMemArray<uint> &sh = _histogram;
Q_ASSERT( i<sh.size() || (_bound || i==sh.size()) );
if ( i==sh.size() )
- return TQString("nb scores greater than %1").arg(sh[sh.size()-1]);
- return TQString("nb scores less than %1").arg(sh[i]);
+ return TQString("nb scores greater than %1").tqarg(sh[sh.size()-1]);
+ return TQString("nb scores less than %1").tqarg(sh[i]);
}
uint PlayerInfos::histoSize() const
@@ -497,10 +497,10 @@ void PlayerInfos::removeKey()
TQString sk;
do {
i++;
- sk = str.arg(HS_KEY).arg(i);
+ sk = str.tqarg(HS_KEY).tqarg(i);
} while ( !cg.config()->readEntry(sk, TQString()).isEmpty() );
cg.config()->writeEntry(sk, key());
- cg.config()->writeEntry(str.arg(HS_REGISTERED_NAME).arg(i),
+ cg.config()->writeEntry(str.tqarg(HS_REGISTERED_NAME).tqarg(i),
registeredName());
// clear current key/nickname
@@ -609,7 +609,7 @@ bool ManagerPrivate::doQuery(const KURL &url, TQWidget *parent,
TQString tmpFile;
if ( !KIO::NetAccess::download(url, tmpFile, parent) ) {
- TQString details = i18n("Server URL: %1").arg(url.host());
+ TQString details = i18n("Server URL: %1").tqarg(url.host());
KMessageBox::detailedSorry(parent, i18n(UNABLE_TO_CONTACT), details);
return false;
}
@@ -647,7 +647,7 @@ bool ManagerPrivate::doQuery(const KURL &url, TQWidget *parent,
}
}
TQString msg = i18n("Invalid answer from world-wide highscores server.");
- TQString details = i18n("Raw message: %1").arg(content);
+ TQString details = i18n("Raw message: %1").tqarg(content);
KMessageBox::detailedSorry(parent, msg, details);
return false;
}
@@ -660,7 +660,7 @@ bool ManagerPrivate::getFromQuery(const TQDomNamedNodeMap &map,
if ( attr.isNull() ) {
KMessageBox::sorry(parent,
i18n("Invalid answer from world-wide "
- "highscores server (missing item: %1).").arg(name));
+ "highscores server (missing item: %1).").tqarg(name));
return false;
}
value = attr.value();
@@ -780,7 +780,7 @@ int ManagerPrivate::submitScore(const Score &ascore,
Score score = ascore;
score.setData("id", _playerInfos->id() + 1);
- score.setData("date", TQDateTime::currentDateTime());
+ score.setData("date", TQDateTime::tqcurrentDateTime());
// ask new name if anonymous and winner
const char *dontAskAgainName = "highscore_ask_name_dialog";
diff --git a/libtdegames/highscore/kexthighscore_item.cpp b/libtdegames/highscore/kexthighscore_item.cpp
index b491d3f8..4b48a0ee 100644
--- a/libtdegames/highscore/kexthighscore_item.cpp
+++ b/libtdegames/highscore/kexthighscore_item.cpp
@@ -19,7 +19,7 @@
#include "kexthighscore_item.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <kglobal.h>
#include <kdialogbase.h>
#include <kdebug.h>
@@ -33,8 +33,8 @@ namespace KExtHighscore
{
//-----------------------------------------------------------------------------
-Item::Item(const TQVariant &def, const TQString &label, int alignment)
- : _default(def), _label(label), _alignment(alignment),
+Item::Item(const TQVariant &def, const TQString &label, int tqalignment)
+ : _default(def), _label(label), _tqalignment(tqalignment),
_format(NoFormat), _special(NoSpecial)
{}
@@ -287,7 +287,7 @@ void MultiplayerScores::show(TQWidget *parent)
vbox = new TQVBox(dialog.plainPage());
hbox->addWidget(vbox);
(void)new TQLabel(i18n("Scores for the last %1 games:")
- .arg(_nbGames[0]), vbox);
+ .tqarg(_nbGames[0]), vbox);
(void)new TotalMultipleScoresList(ordered, vbox);
}
diff --git a/libtdegames/highscore/kexthighscore_tab.cpp b/libtdegames/highscore/kexthighscore_tab.cpp
index 811b1132..d47b35a6 100644
--- a/libtdegames/highscore/kexthighscore_tab.cpp
+++ b/libtdegames/highscore/kexthighscore_tab.cpp
@@ -20,7 +20,7 @@
#include "kexthighscore_tab.h"
#include "kexthighscore_tab.moc"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqvgroupbox.h>
#include <tqgrid.h>
@@ -97,7 +97,7 @@ void AdditionalTab::allSelected()
TQString AdditionalTab::percent(uint n, uint total, bool withBraces)
{
if ( n==0 || total==0 ) return TQString();
- TQString s = TQString("%1%").arg(100.0 * n / total, 0, 'f', 1);
+ TQString s = TQString("%1%").tqarg(100.0 * n / total, 0, 'f', 1);
return (withBraces ? TQString("(") + s + ")" : s);
}
@@ -120,7 +120,7 @@ StatisticsTab::StatisticsTab(TQWidget *parent)
: AdditionalTab(parent, "statistics_tab")
{
// construct GUI
- TQVBoxLayout *top = static_cast<TQVBoxLayout *>(layout());
+ TQVBoxLayout *top = static_cast<TQVBoxLayout *>(tqlayout());
TQHBoxLayout *hbox = new TQHBoxLayout(top);
TQVBoxLayout *vbox = new TQVBoxLayout(hbox);
@@ -209,7 +209,7 @@ HistogramTab::HistogramTab(TQWidget *parent)
: AdditionalTab(parent, "histogram_tab")
{
// construct GUI
- TQVBoxLayout *top = static_cast<TQVBoxLayout *>(layout());
+ TQVBoxLayout *top = static_cast<TQVBoxLayout *>(tqlayout());
_list = new KListView(this);
_list->setSelectionMode(TQListView::NoSelection);
diff --git a/libtdegames/highscore/khighscore.cpp b/libtdegames/highscore/khighscore.cpp
index 3ff2d248..6d696020 100644
--- a/libtdegames/highscore/khighscore.cpp
+++ b/libtdegames/highscore/khighscore.cpp
@@ -96,7 +96,7 @@ void KHighscore::init(const char *appname)
{
#ifdef HIGHSCORE_DIRECTORY
const TQString filename = TQString::fromLocal8Bit("%1/%2.scores")
- .arg(HIGHSCORE_DIRECTORY).arg(appname);
+ .tqarg(HIGHSCORE_DIRECTORY).tqarg(appname);
int fd = open(filename.local8Bit(), O_RDWR);
if ( fd<0 ) kdFatal(11002) << "cannot open global highscore file \""
<< filename << "\"" << endl;
@@ -169,7 +169,7 @@ void KHighscore::writeEntry(int entry, const TQString& key, const TQVariant& val
{
Q_ASSERT( isLocked() );
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
cg.config()->writeEntry(confKey, value);
}
@@ -177,7 +177,7 @@ void KHighscore::writeEntry(int entry, const TQString& key, int value)
{
Q_ASSERT( isLocked() );
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
cg.config()->writeEntry(confKey, value);
}
@@ -185,35 +185,35 @@ void KHighscore::writeEntry(int entry, const TQString& key, const TQString &valu
{
Q_ASSERT (isLocked() );
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
cg.config()->writeEntry(confKey, value);
}
TQVariant KHighscore::readPropertyEntry(int entry, const TQString& key, const TQVariant& pDefault) const
{
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
return cg.config()->readPropertyEntry(confKey, pDefault);
}
TQString KHighscore::readEntry(int entry, const TQString& key, const TQString& pDefault) const
{
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
return cg.config()->readEntry(confKey, pDefault);
}
int KHighscore::readNumEntry(int entry, const TQString& key, int pDefault) const
{
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
return cg.config()->readNumEntry(confKey, pDefault);
}
bool KHighscore::hasEntry(int entry, const TQString& key) const
{
KConfigGroupSaver cg(config(), group());
- TQString confKey = TQString("%1_%2").arg(entry).arg(key);
+ TQString confKey = TQString("%1_%2").tqarg(entry).tqarg(key);
return cg.config()->hasKey(confKey);
}
@@ -248,7 +248,7 @@ TQString KHighscore::group() const
if ( highscoreGroup().isNull() )
return (d->global ? TQString() : GROUP);
return (d->global ? highscoreGroup()
- : TQString("%1_%2").arg(GROUP).arg(highscoreGroup()));
+ : TQString("%1_%2").tqarg(GROUP).tqarg(highscoreGroup()));
}
bool KHighscore::hasTable() const
diff --git a/libtdegames/highscore/khighscore.h b/libtdegames/highscore/khighscore.h
index 3cd14e8c..b7b6fb5e 100644
--- a/libtdegames/highscore/khighscore.h
+++ b/libtdegames/highscore/khighscore.h
@@ -67,7 +67,7 @@ class KHighscorePrivate;
* single player, so the "best times" of a player. To write highscores for a
* specific player in a specific level you will have to use a more complex way:
* \code
- * TQString group = TQString("%1_%2").arg(player).arg(level);
+ * TQString group = TQString("%1_%2").tqarg(player).tqarg(level);
* table->setGroup(group);
* writeHighscore(table, player, level);
* \endcode
diff --git a/libtdegames/highscore/kscoredialog.cpp b/libtdegames/highscore/kscoredialog.cpp
index b22cc232..e799883b 100644
--- a/libtdegames/highscore/kscoredialog.cpp
+++ b/libtdegames/highscore/kscoredialog.cpp
@@ -25,7 +25,7 @@ this software.
#include "config.h"
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlineedit.h>
#include <tqwidgetstack.h>
#include <tqtimer.h>
@@ -44,7 +44,7 @@ class KScoreDialog::KScoreDialogPrivate
public:
TQPtrList<FieldInfo> scores;
TQWidget *page;
- TQGridLayout *layout;
+ TQGridLayout *tqlayout;
TQLineEdit *edit;
TQPtrVector<TQWidgetStack> stack;
TQPtrVector<TQLabel> labels;
@@ -126,36 +126,36 @@ void KScoreDialog::setupDialog()
d->col[field] = d->nrCols++;
}
- d->layout = new TQGridLayout(d->page, 15, d->nrCols, marginHint() + 20, spacingHint());
- d->layout->addRowSpacing(4, 15);
+ d->tqlayout = new TQGridLayout(d->page, 15, d->nrCols, marginHint() + 20, spacingHint());
+ d->tqlayout->addRowSpacing(4, 15);
d->commentLabel = new TQLabel(d->page);
- d->commentLabel->setAlignment(AlignVCenter | AlignHCenter);
- d->layout->addMultiCellWidget(d->commentLabel, 1, 1, 0, d->nrCols-1);
+ d->commentLabel->tqsetAlignment(AlignVCenter | AlignHCenter);
+ d->tqlayout->addMultiCellWidget(d->commentLabel, 1, 1, 0, d->nrCols-1);
TQFont bold = font();
bold.setBold(true);
TQLabel *label;
- d->layout->addColSpacing(0, 50);
+ d->tqlayout->addColSpacing(0, 50);
label = new TQLabel(i18n("Rank"), d->page);
- d->layout->addWidget(label, 3, 0);
+ d->tqlayout->addWidget(label, 3, 0);
label->setFont(bold);
for(int field = 1; field < d->fields; field = field * 2)
{
if (d->fields & field)
{
- d->layout->addColSpacing(d->col[field], 50);
+ d->tqlayout->addColSpacing(d->col[field], 50);
label = new TQLabel(d->header[field], d->page);
- d->layout->addWidget(label, 3, d->col[field], field <= Name ? AlignLeft : AlignRight);
+ d->tqlayout->addWidget(label, 3, d->col[field], field <= Name ? AlignLeft : AlignRight);
label->setFont(bold);
}
}
KSeparator *sep = new KSeparator(Qt::Horizontal, d->page);
- d->layout->addMultiCellWidget(sep, 4, 4, 0, d->nrCols-1);
+ d->tqlayout->addMultiCellWidget(sep, 4, 4, 0, d->nrCols-1);
d->labels.resize(d->nrCols * 10);
d->stack.resize(10);
@@ -164,14 +164,14 @@ void KScoreDialog::setupDialog()
for (int i = 1; i <= 10; ++i) {
TQLabel *label;
num.setNum(i);
- label = new TQLabel(i18n("#%1").arg(num), d->page);
+ label = new TQLabel(i18n("#%1").tqarg(num), d->page);
d->labels.insert((i-1)*d->nrCols + 0, label);
- d->layout->addWidget(label, i+4, 0);
+ d->tqlayout->addWidget(label, i+4, 0);
if (d->fields & Name)
{
TQWidgetStack *stack = new TQWidgetStack(d->page);
d->stack.insert(i-1, stack);
- d->layout->addWidget(stack, i+4, d->col[Name]);
+ d->tqlayout->addWidget(stack, i+4, d->col[Name]);
label = new TQLabel(d->page);
d->labels.insert((i-1)*d->nrCols + d->col[Name], label);
stack->addWidget(label);
@@ -183,7 +183,7 @@ void KScoreDialog::setupDialog()
{
label = new TQLabel(d->page);
d->labels.insert((i-1)*d->nrCols + d->col[field], label);
- d->layout->addWidget(label, i+4, d->col[field], AlignRight);
+ d->tqlayout->addWidget(label, i+4, d->col[field], AlignRight);
}
}
}
@@ -202,15 +202,15 @@ void KScoreDialog::aboutToShow()
{
d->commentLabel->setMinimumSize(TQSize(1,1));
d->commentLabel->hide();
- d->layout->addRowSpacing(0, -15);
- d->layout->addRowSpacing(2, -15);
+ d->tqlayout->addRowSpacing(0, -15);
+ d->tqlayout->addRowSpacing(2, -15);
}
else
{
- d->commentLabel->setMinimumSize(d->commentLabel->sizeHint());
+ d->commentLabel->setMinimumSize(d->commentLabel->tqsizeHint());
d->commentLabel->show();
- d->layout->addRowSpacing(0, -10);
- d->layout->addRowSpacing(2, 10);
+ d->tqlayout->addRowSpacing(0, -10);
+ d->tqlayout->addRowSpacing(2, 10);
}
d->comment = TQString();
@@ -267,7 +267,7 @@ void KScoreDialog::aboutToShow()
}
}
d->latest = -1;
- setFixedSize(minimumSizeHint());
+ setFixedSize(tqminimumSizeHint());
}
void KScoreDialog::loadScores()
diff --git a/libtdegames/kcanvasrootpixmap.cpp b/libtdegames/kcanvasrootpixmap.cpp
index 5e036740..20440458 100644
--- a/libtdegames/kcanvasrootpixmap.cpp
+++ b/libtdegames/kcanvasrootpixmap.cpp
@@ -33,7 +33,7 @@ KCanvasRootPixmap::KCanvasRootPixmap(TQCanvasView *view, const char *name)
void KCanvasRootPixmap::backgroundUpdatedSlot(const TQPixmap &pixmap)
{
if ( _view && _view->canvas() )
- _view->canvas()->setBackgroundPixmap(pixmap);
+ _view->canvas()->tqsetBackgroundPixmap(pixmap);
}
#include "kcanvasrootpixmap.moc"
diff --git a/libtdegames/kcarddialog.cpp b/libtdegames/kcarddialog.cpp
index e45e503e..fc73de22 100644
--- a/libtdegames/kcarddialog.cpp
+++ b/libtdegames/kcarddialog.cpp
@@ -26,7 +26,7 @@
#include <tqgroupbox.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtooltip.h>
#include <tqslider.h>
#include <tqwmatrix.h>
@@ -41,9 +41,9 @@
#include <tqpushbutton.h>
#include <kdebug.h>
-#define KCARD_DEFAULTDECK TQString::fromLatin1("deck0.png")
-#define KCARD_DEFAULTCARD TQString::fromLatin1("11.png")
-#define KCARD_DEFAULTCARDDIR TQString::fromLatin1("cards-default/")
+#define KCARD_DEFAULTDECK TQString::tqfromLatin1("deck0.png")
+#define KCARD_DEFAULTCARD TQString::tqfromLatin1("11.png")
+#define KCARD_DEFAULTCARDDIR TQString::tqfromLatin1("cards-default/")
// values for the resize slider
#define SLIDER_MIN 400
@@ -51,19 +51,19 @@
// KConfig entries
#define CONF_GROUP "KCardDialog"
-#define CONF_RANDOMDECK TQString::fromLatin1("RandomDeck")
-#define CONF_DECK TQString::fromLatin1("Deck")
-#define CONF_CARDDIR TQString::fromLatin1("CardDir")
-#define CONF_RANDOMCARDDIR TQString::fromLatin1("RandomCardDir")
-#define CONF_USEGLOBALDECK TQString::fromLatin1("GlobalDeck")
-#define CONF_USEGLOBALCARDDIR TQString::fromLatin1("GlobalCardDir")
-#define CONF_SCALE TQString::fromLatin1("Scale")
+#define CONF_RANDOMDECK TQString::tqfromLatin1("RandomDeck")
+#define CONF_DECK TQString::tqfromLatin1("Deck")
+#define CONF_CARDDIR TQString::tqfromLatin1("CardDir")
+#define CONF_RANDOMCARDDIR TQString::tqfromLatin1("RandomCardDir")
+#define CONF_USEGLOBALDECK TQString::tqfromLatin1("GlobalDeck")
+#define CONF_USEGLOBALCARDDIR TQString::tqfromLatin1("GlobalCardDir")
+#define CONF_SCALE TQString::tqfromLatin1("Scale")
-#define CONF_GLOBAL_GROUP TQString::fromLatin1("KCardDialog Settings")
-#define CONF_GLOBAL_DECK TQString::fromLatin1("GlobalDeck")
-#define CONF_GLOBAL_CARDDIR TQString::fromLatin1("GlobalCardDir")
-#define CONF_GLOBAL_RANDOMDECK TQString::fromLatin1("GlobalRandomDeck")
-#define CONF_GLOBAL_RANDOMCARDDIR TQString::fromLatin1("GlobalRandomCardDir")
+#define CONF_GLOBAL_GROUP TQString::tqfromLatin1("KCardDialog Settings")
+#define CONF_GLOBAL_DECK TQString::tqfromLatin1("GlobalDeck")
+#define CONF_GLOBAL_CARDDIR TQString::tqfromLatin1("GlobalCardDir")
+#define CONF_GLOBAL_RANDOMDECK TQString::tqfromLatin1("GlobalRandomDeck")
+#define CONF_GLOBAL_RANDOMCARDDIR TQString::tqfromLatin1("GlobalRandomCardDir")
class KCardDialogPrivate
@@ -128,9 +128,9 @@ int KCardDialog::getCardDeck(TQString &pDeck, TQString &pCardDir, TQWidget *pPar
// TODO check for global cards/decks!!!!
pDeck=dlg.deck();
pCardDir=dlg.cardDir();
- if (!pCardDir.isNull() && pCardDir.right(1)!=TQString::fromLatin1("/"))
+ if (!pCardDir.isNull() && pCardDir.right(1)!=TQString::tqfromLatin1("/"))
{
- pCardDir+=TQString::fromLatin1("/");
+ pCardDir+=TQString::tqfromLatin1("/");
}
if (pRandomDeck)
{
@@ -218,7 +218,7 @@ void KCardDialog::getConfigCardDeck(KConfig* conf, TQString &pDeck, TQString &pC
TQString KCardDialog::getDefaultDeck()
{
KCardDialog::init();
- return locate("cards", TQString::fromLatin1("decks/") + KCARD_DEFAULTDECK);
+ return locate("cards", TQString::tqfromLatin1("decks/") + KCARD_DEFAULTDECK);
}
TQString KCardDialog::getDefaultCardDir()
@@ -234,12 +234,12 @@ TQString KCardDialog::getCardPath(const TQString &carddir, int index)
KCardDialog::init();
TQString entry = carddir + TQString::number(index);
- if (KStandardDirs::exists(entry + TQString::fromLatin1(".png")))
- return entry + TQString::fromLatin1(".png");
+ if (KStandardDirs::exists(entry + TQString::tqfromLatin1(".png")))
+ return entry + TQString::tqfromLatin1(".png");
// rather theoretical
- if (KStandardDirs::exists(entry + TQString::fromLatin1(".xpm")))
- return entry + TQString::fromLatin1(".xpm");
+ if (KStandardDirs::exists(entry + TQString::tqfromLatin1(".xpm")))
+ return entry + TQString::tqfromLatin1(".xpm");
return TQString();
}
@@ -271,11 +271,11 @@ void KCardDialog::setupDialog(bool showResizeBox)
if (! (flags() & NoDeck))
{
- TQHBoxLayout* layout = new TQHBoxLayout(cardLayout);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(cardLayout);
// Deck iconview
TQGroupBox* grp1 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Backside"), plainPage());
- layout->addWidget(grp1);
+ tqlayout->addWidget(grp1);
d->deckIconView = new KIconView(grp1,"decks");
d->deckIconView->setSpacing(8);
@@ -293,13 +293,13 @@ void KCardDialog::setupDialog(bool showResizeBox)
d->deckIconView->showToolTips();
// deck select
- TQVBoxLayout* l = new TQVBoxLayout(layout);
+ TQVBoxLayout* l = new TQVBoxLayout(tqlayout);
TQGroupBox* grp3 = new TQGroupBox(i18n("Backside"), plainPage());
grp3->setFixedSize(100, 130);
l->addWidget(grp3, 0, AlignTop|AlignHCenter);
d->deckLabel = new TQLabel(grp3);
d->deckLabel->setText(i18n("empty"));
- d->deckLabel->setAlignment(AlignHCenter|AlignVCenter);
+ d->deckLabel->tqsetAlignment(AlignHCenter|AlignVCenter);
d->deckLabel->setGeometry(10, 20, 80, 90);
d->randomDeck = new TQCheckBox(plainPage());
@@ -325,9 +325,9 @@ void KCardDialog::setupDialog(bool showResizeBox)
if (! (flags() & NoCards))
{
// Cards iconview
- TQHBoxLayout* layout = new TQHBoxLayout(cardLayout);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(cardLayout);
TQGroupBox* grp2 = new TQGroupBox(1,Qt::Horizontal, i18n("Choose Frontside"), plainPage());
- layout->addWidget(grp2);
+ tqlayout->addWidget(grp2);
d->cardIconView =new KIconView(grp2,"cards");
/*
@@ -343,13 +343,13 @@ void KCardDialog::setupDialog(bool showResizeBox)
d->cardIconView->showToolTips();
// Card select
- TQVBoxLayout* l = new TQVBoxLayout(layout);
+ TQVBoxLayout* l = new TQVBoxLayout(tqlayout);
TQGroupBox* grp4 = new TQGroupBox(i18n("Frontside"), plainPage());
grp4->setFixedSize(100, 130);
l->addWidget(grp4, 0, AlignTop|AlignHCenter);
d->cardLabel = new TQLabel(grp4);
d->cardLabel->setText(i18n("empty"));
- d->cardLabel->setAlignment(AlignHCenter|AlignVCenter);
+ d->cardLabel->tqsetAlignment(AlignHCenter|AlignVCenter);
d->cardLabel->setGeometry(10, 20, 80, 90 );
d->randomCardDir = new TQCheckBox(plainPage());
@@ -422,10 +422,10 @@ void KCardDialog::setupDialog(bool showResizeBox)
// large. This is desired behaviour as i don't want to make the box even
// larger but i want the complete pixmap to be displayed. the dialog is not
// resized if you make the pixmap smaller again.
- TQVBoxLayout* layout = new TQVBoxLayout(topLayout);
+ TQVBoxLayout* tqlayout = new TQVBoxLayout(topLayout);
TQGroupBox* grp = new TQGroupBox(1,Qt::Horizontal, i18n("Resize Cards"), plainPage());
- layout->setResizeMode(TQLayout::Fixed);
- layout->addWidget(grp);
+ tqlayout->setResizeMode(TQLayout::Fixed);
+ tqlayout->addWidget(grp);
TQWidget* box = new TQWidget(grp);
TQHBoxLayout* hbox = new TQHBoxLayout(box, 0, spacingHint());
TQVBoxLayout* boxLayout = new TQVBoxLayout(hbox);
@@ -465,7 +465,7 @@ void KCardDialog::insertCardIcons()
for (TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
{
KSimpleConfig cfg(*it);
- cfg.setGroup(TQString::fromLatin1("KDE Backdeck"));
+ cfg.setGroup(TQString::tqfromLatin1("KDE Backdeck"));
TQString path = (*it).left((*it).findRev('/') + 1);
assert(path[path.length() - 1] == '/');
TQPixmap pixmap(path + cfg.readEntry("Preview", "12c.png"));
@@ -507,7 +507,7 @@ void KCardDialog::insertDeckIcons()
// pixmap=pixmap.xForm(m);
- cfg.setGroup(TQString::fromLatin1("KDE Cards"));
+ cfg.setGroup(TQString::tqfromLatin1("KDE Cards"));
TQString name=cfg.readEntry("Name", i18n("unnamed"));
TQIconViewItem *item= new TQIconViewItem(d->deckIconView,name, pixmap);
@@ -562,12 +562,12 @@ void KCardDialog::slotCardClicked(TQIconViewItem *item)
TQString KCardDialog::getDeckName(const TQString &desktop)
{
TQString entry = desktop.left(desktop.length() - strlen(".desktop"));
- if (KStandardDirs::exists(entry + TQString::fromLatin1(".png")))
- return entry + TQString::fromLatin1(".png");
+ if (KStandardDirs::exists(entry + TQString::tqfromLatin1(".png")))
+ return entry + TQString::tqfromLatin1(".png");
// rather theoretical
- if (KStandardDirs::exists(entry + TQString::fromLatin1(".xpm")))
- return entry + TQString::fromLatin1(".xpm");
+ if (KStandardDirs::exists(entry + TQString::tqfromLatin1(".xpm")))
+ return entry + TQString::tqfromLatin1(".xpm");
return TQString();
}
@@ -634,8 +634,8 @@ void KCardDialog::slotRandomCardDirToggled(bool on)
if (on) {
d->cardLabel->setText("random");
setCardDir(getRandomCardDir());
- if (cardDir().length()>0 && cardDir().right(1)!=TQString::fromLatin1("/")) {
- setCardDir(cardDir() + TQString::fromLatin1("/"));
+ if (cardDir().length()>0 && cardDir().right(1)!=TQString::tqfromLatin1("/")) {
+ setCardDir(cardDir() + TQString::tqfromLatin1("/"));
}
} else {
d->cardLabel->setText("empty");
@@ -742,7 +742,7 @@ void KCardDialog::saveConfig(KConfig* conf)
void KCardDialog::slotSetGlobalDeck()
{
- KSimpleConfig* conf = new KSimpleConfig(TQString::fromLatin1("kdeglobals"), false);
+ KSimpleConfig* conf = new KSimpleConfig(TQString::tqfromLatin1("kdeglobals"), false);
conf->setGroup(CONF_GLOBAL_GROUP);
conf->writeEntry(CONF_GLOBAL_DECK, deck());
@@ -753,7 +753,7 @@ void KCardDialog::slotSetGlobalDeck()
void KCardDialog::slotSetGlobalCardDir()
{
- KSimpleConfig* conf = new KSimpleConfig(TQString::fromLatin1("kdeglobals"), false);
+ KSimpleConfig* conf = new KSimpleConfig(TQString::tqfromLatin1("kdeglobals"), false);
conf->setGroup(CONF_GLOBAL_GROUP);
conf->writePathEntry(CONF_GLOBAL_CARDDIR, cardDir());
@@ -764,7 +764,7 @@ void KCardDialog::slotSetGlobalCardDir()
void KCardDialog::getGlobalDeck(TQString& deck, bool& random)
{
- KSimpleConfig* conf = new KSimpleConfig(TQString::fromLatin1("kdeglobals"), true);
+ KSimpleConfig* conf = new KSimpleConfig(TQString::tqfromLatin1("kdeglobals"), true);
conf->setGroup(CONF_GLOBAL_GROUP);
if (!conf->hasKey(CONF_GLOBAL_DECK) || conf->readBoolEntry(CONF_GLOBAL_RANDOMDECK, false)) {
@@ -780,7 +780,7 @@ void KCardDialog::getGlobalDeck(TQString& deck, bool& random)
void KCardDialog::getGlobalCardDir(TQString& dir, bool& random)
{
- KSimpleConfig* conf = new KSimpleConfig(TQString::fromLatin1("kdeglobals"), true);
+ KSimpleConfig* conf = new KSimpleConfig(TQString::tqfromLatin1("kdeglobals"), true);
conf->setGroup(CONF_GLOBAL_GROUP);
if (!conf->hasKey(CONF_GLOBAL_CARDDIR) || conf->readBoolEntry(CONF_GLOBAL_RANDOMCARDDIR, false)) {
@@ -799,7 +799,7 @@ void KCardDialog::init()
static bool _inited = false;
if (_inited)
return;
- KGlobal::dirs()->addResourceType("cards", KStandardDirs::kde_default("data") + TQString::fromLatin1("carddecks/"));
+ KGlobal::dirs()->addResourceType("cards", KStandardDirs::kde_default("data") + TQString::tqfromLatin1("carddecks/"));
KGlobal::locale()->insertCatalogue("libtdegames");
_inited = true;
diff --git a/libtdegames/kchatbase.cpp b/libtdegames/kchatbase.cpp
index 06b5b5d5..14f74103 100644
--- a/libtdegames/kchatbase.cpp
+++ b/libtdegames/kchatbase.cpp
@@ -26,7 +26,7 @@
#include <kapplication.h>
#include <kdebug.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcombobox.h>
#include <tqpainter.h>
@@ -73,14 +73,14 @@ void KChatBaseText::init()
void KChatBaseText::setName(const TQString& n)
{
// d->mName = n;
- d->mName = TQString("%1: ").arg(n);
- setText(TQString("%1: %2").arg(name()).arg(message())); // esp. for sorting
+ d->mName = TQString("%1: ").tqarg(n);
+ setText(TQString("%1: %2").tqarg(name()).tqarg(message())); // esp. for sorting
}
void KChatBaseText::setMessage(const TQString& m)
{
d->mMessage = m;
- setText(TQString("%1: %2").arg(name()).arg(message())); // esp. for sorting
+ setText(TQString("%1: %2").tqarg(name()).tqarg(message())); // esp. for sorting
}
const TQString& KChatBaseText::name() const
@@ -364,11 +364,11 @@ TQListBoxItem* KChatBase::layoutMessage(const TQString& fromName, const TQString
if (text.startsWith("/me ")) {
// replace "/me" by a nice star. leave one space after the star
TQPixmap pix;
- pix.load(locate("data", TQString::fromLatin1("tdegames/pics/star.png")));
+ pix.load(locate("data", TQString::tqfromLatin1("tdegames/pics/star.png")));
//TODO KChatBasePixmap? Should change the font here!
- message = (TQListBoxItem*)new TQListBoxPixmap(pix, i18n("%1 %2").arg(fromName).arg(text.mid(3)));
+ message = (TQListBoxItem*)new TQListBoxPixmap(pix, i18n("%1 %2").tqarg(fromName).tqarg(text.mid(3)));
} else {
// the text is not edited in any way. just return an item
KChatBaseText* m = new KChatBaseText(fromName, text);
@@ -384,7 +384,7 @@ TQListBoxItem* KChatBase::layoutSystemMessage(const TQString& fromName, const TQ
//TODO: KChatBaseConfigure? - e.g. color
// no need to check for /me etc.
- KChatBaseText* m = new KChatBaseText(i18n("--- %1").arg(fromName), text);
+ KChatBaseText* m = new KChatBaseText(i18n("--- %1").tqarg(fromName), text);
m->setNameFont(&d->mSystemNameFont);
m->setMessageFont(&d->mSystemMessageFont);
return (TQListBoxItem*)m;
@@ -406,7 +406,7 @@ void KChatBase::slotReturnPressed(const TQString& text)
TQString KChatBase::comboBoxItem(const TQString& name) const
{ // TODO: such a function for "send to all" and "send to my group"
- return i18n("Send to %1").arg(name);
+ return i18n("Send to %1").tqarg(name);
}
void KChatBase::slotClear()
diff --git a/libtdegames/kchatbase.h b/libtdegames/kchatbase.h
index 33ba3d76..892e5859 100644
--- a/libtdegames/kchatbase.h
+++ b/libtdegames/kchatbase.h
@@ -471,7 +471,7 @@ protected:
/**
* Replace to customise the combo box.
*
- * Default: i18n("Send to %1).arg(name)
+ * Default: i18n("Send to %1).tqarg(name)
* @param name The name of the player
* @return The string as it will be shown in the combo box
**/
diff --git a/libtdegames/kchatdialog.cpp b/libtdegames/kchatdialog.cpp
index 002384a2..7e0df7e8 100644
--- a/libtdegames/kchatdialog.cpp
+++ b/libtdegames/kchatdialog.cpp
@@ -24,7 +24,7 @@
#include <klocale.h>
#include <kfontdialog.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
@@ -80,42 +80,42 @@ void KChatDialog::init()
d = new KChatDialogPrivate;
// d->mTextPage = addPage(i18n("&Messages"));// not a good name - game Messages?
d->mTextPage = plainPage();
- TQGridLayout* layout = new TQGridLayout(d->mTextPage, 7, 2, KDialog::marginHint(), KDialog::spacingHint());
+ TQGridLayout* tqlayout = new TQGridLayout(d->mTextPage, 7, 2, KDialog::marginHint(), KDialog::spacingHint());
// General fonts
TQPushButton* nameFont = new TQPushButton(i18n("Name Font..."), d->mTextPage);
connect(nameFont, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotGetNameFont()));
- layout->addWidget(nameFont, 0, 0);
+ tqlayout->addWidget(nameFont, 0, 0);
TQPushButton* textFont = new TQPushButton(i18n("Text Font..."), d->mTextPage);
connect(textFont, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotGetTextFont()));
- layout->addWidget(textFont, 0, 1);
+ tqlayout->addWidget(textFont, 0, 1);
TQFrame* messagePreview = new TQFrame(d->mTextPage);
messagePreview->setFrameStyle(TQFrame::StyledPanel | TQFrame::Sunken);
TQHBoxLayout* messageLayout = new TQHBoxLayout(messagePreview);
- layout->addMultiCellWidget(messagePreview, 1, 1, 0, 1);
+ tqlayout->addMultiCellWidget(messagePreview, 1, 1, 0, 1);
d->mNamePreview = new TQLabel(i18n("Player: "), messagePreview);
messageLayout->addWidget(d->mNamePreview, 0);
d->mTextPreview = new TQLabel(i18n("This is a player message"), messagePreview);
messageLayout->addWidget(d->mTextPreview, 1);
- layout->addRowSpacing(2, 10);
+ tqlayout->addRowSpacing(2, 10);
// System Message fonts
TQLabel* systemMessages = new TQLabel(i18n("System Messages - Messages directly sent from the game"), d->mTextPage);
- layout->addMultiCellWidget(systemMessages, 3, 3, 0, 1);
+ tqlayout->addMultiCellWidget(systemMessages, 3, 3, 0, 1);
TQPushButton* systemNameFont = new TQPushButton(i18n("Name Font..."), d->mTextPage);
connect(systemNameFont, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotGetSystemNameFont()));
- layout->addWidget(systemNameFont, 4, 0);
+ tqlayout->addWidget(systemNameFont, 4, 0);
TQPushButton* systemTextFont = new TQPushButton(i18n("Text Font..."), d->mTextPage);
connect(systemTextFont, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotGetSystemTextFont()));
- layout->addWidget(systemTextFont, 4, 1);
+ tqlayout->addWidget(systemTextFont, 4, 1);
TQFrame* systemMessagePreview = new TQFrame(d->mTextPage);
systemMessagePreview->setFrameStyle(TQFrame::StyledPanel | TQFrame::Sunken);
TQHBoxLayout* systemMessageLayout = new TQHBoxLayout(systemMessagePreview);
- layout->addMultiCellWidget(systemMessagePreview, 5, 5, 0, 1);
+ tqlayout->addMultiCellWidget(systemMessagePreview, 5, 5, 0, 1);
d->mSystemNamePreview = new TQLabel(i18n("--- Game: "), systemMessagePreview);
systemMessageLayout->addWidget(d->mSystemNamePreview, 0);
@@ -124,10 +124,10 @@ void KChatDialog::init()
// message count
TQLabel* maxMessages = new TQLabel(i18n("Maximal number of messages (-1 = unlimited):"), d->mTextPage);
- layout->addWidget(maxMessages, 6, 0);
+ tqlayout->addWidget(maxMessages, 6, 0);
d->mMaxMessages = new TQLineEdit(d->mTextPage);
d->mMaxMessages->setText(TQString::number(-1));
- layout->addWidget(d->mMaxMessages, 6, 1);
+ tqlayout->addWidget(d->mMaxMessages, 6, 1);
}
void KChatDialog::slotGetNameFont()
diff --git a/libtdegames/kgame/COMPAT b/libtdegames/kgame/COMPAT
index b85ec9b6..4551c679 100644
--- a/libtdegames/kgame/COMPAT
+++ b/libtdegames/kgame/COMPAT
@@ -38,7 +38,7 @@
too!
The API stays the same.
11.10.2001 KGameDialogGeneralConfig now doesn't provide setMin/maxPlayers()
- anymore. The game should manage this internally. layout() is
+ anymore. The game should manage this internally. tqlayout() is
obsolete as well
18.10.2001 KPlayer::signalNetworkData contained QDataStream& instead of const
QByteArray& parameter (oops!). This is fixed now. All apps which
diff --git a/libtdegames/kgame/DESIGN b/libtdegames/kgame/DESIGN
index b1c48146..cd737e3a 100644
--- a/libtdegames/kgame/DESIGN
+++ b/libtdegames/kgame/DESIGN
@@ -359,7 +359,7 @@ KDialogBase::addVBoxPage() (for example).
5.1.1 Debug KGame
-----------------
The first page, "Debug KGame" shows on the left most or even all status values of
-KGame. That contains e.g. minPlayers(), isAdmin(), gameStatus(), ...
+KGame. That contains e.g. minPlayers(), isAdmin(), gametqStatus(), ...
The right side is probably the more important one. It lists *all* KGameProperties
which have been inserted to this KGame object (only to this KGame object - not
the ones that have been added to the players!). Most of the status variables of
diff --git a/libtdegames/kgame/dialogs/kgameconnectdialog.cpp b/libtdegames/kgame/dialogs/kgameconnectdialog.cpp
index 009c4e76..98958ffd 100644
--- a/libtdegames/kgame/dialogs/kgameconnectdialog.cpp
+++ b/libtdegames/kgame/dialogs/kgameconnectdialog.cpp
@@ -27,7 +27,7 @@
#include <tqlineedit.h>
#include <tqcombobox.h>
#include <tqvbuttongroup.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqradiobutton.h>
#include <tqlabel.h>
#include <dnssd/servicebrowser.h>
diff --git a/libtdegames/kgame/dialogs/kgamedebugdialog.cpp b/libtdegames/kgame/dialogs/kgamedebugdialog.cpp
index 11745f21..49623238 100644
--- a/libtdegames/kgame/dialogs/kgamedebugdialog.cpp
+++ b/libtdegames/kgame/dialogs/kgamedebugdialog.cpp
@@ -32,7 +32,7 @@
#include <kpushbutton.h>
#include <kstdguiitem.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqstring.h>
#include <tqintdict.h>
#include <tqlabel.h>
@@ -56,7 +56,7 @@ public:
mGameMaster = 0;
mGameAdmin = 0;
mGameOffering = 0;
- mGameStatus = 0;
+ mGametqStatus = 0;
mGameRunning = 0;
mGameMaxPlayers = 0;
mGameMinPlayers = 0;
@@ -93,7 +93,7 @@ public:
TQListViewItem* mGameMaster;
TQListViewItem* mGameAdmin;
TQListViewItem* mGameOffering;
- TQListViewItem* mGameStatus;
+ TQListViewItem* mGametqStatus;
TQListViewItem* mGameRunning;
TQListViewItem* mGameMaxPlayers;
TQListViewItem* mGameMinPlayers;
@@ -142,18 +142,18 @@ void KGameDebugDialog::initGamePage()
{
d->mGamePage = addPage(i18n("Debug &KGame"));
TQVBoxLayout* topLayout = new TQVBoxLayout(d->mGamePage, marginHint(), spacingHint());
- TQHBoxLayout* layout = new TQHBoxLayout(topLayout);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(topLayout);
KListView* v = new KListView(d->mGamePage);
v->addColumn(i18n("Data"));
v->addColumn(i18n("Value"));
- layout->addWidget(v);
+ tqlayout->addWidget(v);
d->mGameProperties = new KListView(d->mGamePage);
d->mGameProperties->addColumn(i18n("Property"));
d->mGameProperties->addColumn(i18n("Value"));
d->mGameProperties->addColumn(i18n("Policy"));
- layout->addWidget(d->mGameProperties);
+ tqlayout->addWidget(d->mGameProperties);
TQPushButton* b = new TQPushButton(i18n("Update"), d->mGamePage);
connect(b, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotUpdateGameData()));
@@ -166,7 +166,7 @@ void KGameDebugDialog::initGamePage()
d->mGameMaster = new TQListViewItem(v, i18n("Is Master"));
d->mGameAdmin = new TQListViewItem(v, i18n("Is Admin"));
d->mGameOffering = new TQListViewItem(v, i18n("Is Offering Connections"));
- d->mGameStatus = new TQListViewItem(v, i18n("Game Status"));
+ d->mGametqStatus = new TQListViewItem(v, i18n("Game Status"));
d->mGameRunning = new TQListViewItem(v, i18n("Game is Running"));
d->mGameMaxPlayers = new TQListViewItem(v, i18n("Maximal Players"));
d->mGameMinPlayers = new TQListViewItem(v, i18n("Minimal Players"));
@@ -177,19 +177,19 @@ void KGameDebugDialog::initPlayerPage()
{
d->mPlayerPage = addPage(i18n("Debug &Players"));
TQVBoxLayout* topLayout = new TQVBoxLayout(d->mPlayerPage, marginHint(), spacingHint());
- TQHBoxLayout* layout = new TQHBoxLayout(topLayout);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(topLayout);
//TODO: connect to the KGame signals for joined/removed players!!!
- TQVBoxLayout* listLayout = new TQVBoxLayout(layout);
+ TQVBoxLayout* listLayout = new TQVBoxLayout(tqlayout);
TQLabel* listLabel = new TQLabel(i18n("Available Players"), d->mPlayerPage);
listLayout->addWidget(listLabel);
d->mPlayerList = new KListBox(d->mPlayerPage);
connect(d->mPlayerList, TQT_SIGNAL(executed(TQListBoxItem*)), this, TQT_SLOT(slotUpdatePlayerData(TQListBoxItem*)));
listLayout->addWidget(d->mPlayerList);
- d->mPlayerList->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding));
+ d->mPlayerList->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding));
KListView* v = new KListView(d->mPlayerPage);
- layout->addWidget(v);
+ tqlayout->addWidget(v);
v->addColumn(i18n("Data"));
v->addColumn(i18n("Value"));
@@ -197,7 +197,7 @@ void KGameDebugDialog::initPlayerPage()
d->mPlayerProperties->addColumn(i18n("Property"));
d->mPlayerProperties->addColumn(i18n("Value"));
d->mPlayerProperties->addColumn(i18n("Policy"));
- layout->addWidget(d->mPlayerProperties);
+ tqlayout->addWidget(d->mPlayerProperties);
TQPushButton* b = new TQPushButton(i18n("Update"), d->mPlayerPage);
connect(b, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotUpdatePlayerList()));
@@ -220,9 +220,9 @@ void KGameDebugDialog::initPlayerPage()
void KGameDebugDialog::initMessagePage()
{
d->mMessagePage = addPage(i18n("Debug &Messages"));
- TQGridLayout* layout = new TQGridLayout(d->mMessagePage, 11, 7, marginHint(), spacingHint());
+ TQGridLayout* tqlayout = new TQGridLayout(d->mMessagePage, 11, 7, marginHint(), spacingHint());
d->mMessageList = new KListView(d->mMessagePage);
- layout->addMultiCellWidget(d->mMessageList, 0, 9, 0, 3);
+ tqlayout->addMultiCellWidget(d->mMessageList, 0, 9, 0, 3);
d->mMessageList->addColumn(i18n("Time"));
d->mMessageList->addColumn(i18n("ID"));
d->mMessageList->addColumn(i18n("Receiver"));
@@ -231,20 +231,20 @@ void KGameDebugDialog::initMessagePage()
TQPushButton* hide = new TQPushButton(i18n("&>>"), d->mMessagePage);
connect(hide, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotHideId()));
- layout->addWidget(hide, 4, 4);
+ tqlayout->addWidget(hide, 4, 4);
TQPushButton* show = new TQPushButton(i18n("&<<"), d->mMessagePage);
connect(show, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotShowId()));
- layout->addWidget(show, 6, 4);
+ tqlayout->addWidget(show, 6, 4);
TQLabel* l = new TQLabel(i18n("Do not show IDs:"), d->mMessagePage);
- layout->addMultiCellWidget(l, 0, 0, 5, 6);
+ tqlayout->addMultiCellWidget(l, 0, 0, 5, 6);
d->mHideIdList = new KListBox(d->mMessagePage);
- layout->addMultiCellWidget(d->mHideIdList, 1, 8, 5, 6);
+ tqlayout->addMultiCellWidget(d->mHideIdList, 1, 8, 5, 6);
TQPushButton* clear = new KPushButton(KStdGuiItem::clear(), d->mMessagePage);
connect(clear, TQT_SIGNAL(pressed()), this, TQT_SLOT(slotClearMessages()));
- layout->addMultiCellWidget(clear, 10, 10, 0, 6);
+ tqlayout->addMultiCellWidget(clear, 10, 10, 0, 6);
//TODO: "show all but..." and "show nothing but..."
}
@@ -274,7 +274,7 @@ void KGameDebugDialog::clearGameData()
d->mGameMaster->setText(1, "");
d->mGameAdmin->setText(1, "");
d->mGameOffering->setText(1, "");
- d->mGameStatus->setText(1, "");
+ d->mGametqStatus->setText(1, "");
d->mGameRunning->setText(1, "");
d->mGameMaxPlayers->setText(1, "");
d->mGameMinPlayers->setText(1, "");
@@ -320,7 +320,7 @@ void KGameDebugDialog::slotUpdateGameData()
d->mGameMaster->setText(1, d->mGame->isMaster() ? i18n("True") : i18n("False"));
d->mGameAdmin->setText(1, d->mGame->isAdmin() ? i18n("True") : i18n("False"));
d->mGameOffering->setText(1, d->mGame->isOfferingConnections() ? i18n("True") : i18n("False"));
- d->mGameStatus->setText(1, TQString::number(d->mGame->gameStatus()));
+ d->mGametqStatus->setText(1, TQString::number(d->mGame->gametqStatus()));
d->mGameRunning->setText(1, d->mGame->isRunning() ? i18n("True") : i18n("False"));
d->mGameMaxPlayers->setText(1, TQString::number(d->mGame->maxPlayers()));
d->mGameMinPlayers->setText(1, TQString::number(d->mGame->minPlayers()));
diff --git a/libtdegames/kgame/dialogs/kgamedialog.cpp b/libtdegames/kgame/dialogs/kgamedialog.cpp
index dc85cd6a..c03df4ff 100644
--- a/libtdegames/kgame/dialogs/kgamedialog.cpp
+++ b/libtdegames/kgame/dialogs/kgamedialog.cpp
@@ -18,7 +18,7 @@
Boston, MA 02110-1301, USA.
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqvbox.h>
#include <klocale.h>
diff --git a/libtdegames/kgame/dialogs/kgamedialogconfig.cpp b/libtdegames/kgame/dialogs/kgamedialogconfig.cpp
index c57ed7f6..f6845650 100644
--- a/libtdegames/kgame/dialogs/kgamedialogconfig.cpp
+++ b/libtdegames/kgame/dialogs/kgamedialogconfig.cpp
@@ -31,7 +31,7 @@
#include <klistbox.h>
#include <kmessagebox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqhgroupbox.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
@@ -122,7 +122,7 @@ KGameDialogNetworkConfig::KGameDialogNetworkConfig(TQWidget* parent)
// kdDebug(11001) << k_funcinfo << ": this=" << this << endl;
d = new KGameDialogNetworkConfigPrivate();
- TQVBoxLayout* topLayout = new TQVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint(), "toplayout");
+ TQVBoxLayout* topLayout = new TQVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint(), "toptqlayout");
TQHBoxLayout *hb = new TQHBoxLayout(topLayout, KDialog::spacingHint());
@@ -743,7 +743,7 @@ void KGameDialogConnectionConfig::slotKickPlayerOut(TQListBoxItem* item)
return;
}
- if (KMessageBox::questionYesNo(this, i18n("Do you want to ban player \"%1\" from the game?").arg(
+ if (KMessageBox::questionYesNo(this, i18n("Do you want to ban player \"%1\" from the game?").tqarg(
p->name()), TQString(), i18n("Ban Player"), i18n("Do Not Ban")) == KMessageBox::Yes) {
kdDebug(11001) << "will remove player " << p << endl;
game()->removePlayer(p);
diff --git a/libtdegames/kgame/dialogs/kgamedialogconfig.h b/libtdegames/kgame/dialogs/kgamedialogconfig.h
index b91f05d0..c2c36e2a 100644
--- a/libtdegames/kgame/dialogs/kgamedialogconfig.h
+++ b/libtdegames/kgame/dialogs/kgamedialogconfig.h
@@ -157,7 +157,7 @@ public:
*
* @param parent Parent widget for this dialog.
* @param initializeGUI If you really don't want to use the
- * predefined widget and/or layout use FALSE here. Note that then none
+ * predefined widget and/or tqlayout use FALSE here. Note that then none
* of the predefined widgets (currently only the name of the player)
* will exist anymore.
*
diff --git a/libtdegames/kgame/dialogs/kgameerrordialog.cpp b/libtdegames/kgame/dialogs/kgameerrordialog.cpp
index e22211c3..6ab9d71c 100644
--- a/libtdegames/kgame/dialogs/kgameerrordialog.cpp
+++ b/libtdegames/kgame/dialogs/kgameerrordialog.cpp
@@ -86,7 +86,7 @@ void KGameErrorDialog::slotClientConnectionLost(TQ_UINT32 /*id*/,bool)
//TODO: add IP/port of the client
TQString message;
// if (c) {
-// message = i18n("Connection to client has been lost!\nID: %1\nIP: %2").arg(c->id()).arg(c->IP());
+// message = i18n("Connection to client has been lost!\nID: %1\nIP: %2").tqarg(c->id()).tqarg(c->IP());
// } else {
// message = i18n("Connection to client has been lost!");
// }
@@ -96,7 +96,7 @@ void KGameErrorDialog::slotClientConnectionLost(TQ_UINT32 /*id*/,bool)
void KGameErrorDialog::slotError(int errorNo, TQString text)
{
- TQString message = i18n("Received a network error!\nError number: %1\nError message: %2").arg(errorNo).arg(text);
+ TQString message = i18n("Received a network error!\nError number: %1\nError message: %2").tqarg(errorNo).tqarg(text);
error(message, (TQWidget*)parent());
}
@@ -106,7 +106,7 @@ void KGameErrorDialog::connectionError(TQString s)
if (s.isNull()) {
message = i18n("No connection could be created.");
} else {
- message = i18n("No connection could be created.\nThe error message was:\n%1").arg(s);
+ message = i18n("No connection could be created.\nThe error message was:\n%1").tqarg(s);
}
error(message, (TQWidget*)parent());
}
diff --git a/libtdegames/kgame/kgame.cpp b/libtdegames/kgame/kgame.cpp
index c2f7f583..2eebac64 100644
--- a/libtdegames/kgame/kgame.cpp
+++ b/libtdegames/kgame/kgame.cpp
@@ -75,7 +75,7 @@ public:
//KGamePropertys
KGamePropertyInt mMaxPlayer;
KGamePropertyUInt mMinPlayer;
- KGamePropertyInt mGameStatus; // Game running?
+ KGamePropertyInt mGametqStatus; // Game running?
TQValueList<int> mInactiveIdList;
};
@@ -95,8 +95,8 @@ KGame::KGame(int cookie,TQObject* parent) : KGameNetwork(cookie,parent)
d->mMaxPlayer.setLocal(-1); // Infinite
d->mMinPlayer.registerData(KGamePropertyBase::IdMinPlayer, this, i18n("MinPlayers"));
d->mMinPlayer.setLocal(0); // Always ok
- d->mGameStatus.registerData(KGamePropertyBase::IdGameStatus, this, i18n("GameStatus"));
- d->mGameStatus.setLocal(Init);
+ d->mGametqStatus.registerData(KGamePropertyBase::IdGametqStatus, this, i18n("GameStatus"));
+ d->mGametqStatus.setLocal(Init);
// d->mUniquePlayerNumber = 0;
d->mRandom = new KRandomSequence;
d->mRandom->setSeed(0);
@@ -542,10 +542,10 @@ void KGame::systemRemovePlayer(KPlayer* player,bool deleteit)
kdWarning(11001) << "player " << player << "(" << player->id() << ") Could not be found!" << endl;
}
- if (gameStatus()==(int)Run && playerCount()<minPlayers())
+ if (gametqStatus()==(int)Run && playerCount()<minPlayers())
{
kdWarning(11001) << k_funcinfo ": not enough players, PAUSING game\n" << endl;
- setGameStatus(Pause);
+ setGametqStatus(Pause);
}
}
@@ -680,11 +680,11 @@ int KGame::maxPlayers() const
uint KGame::playerCount() const
{ return d->mPlayerList.count(); }
-int KGame::gameStatus() const
-{ return d->mGameStatus.value(); }
+int KGame::gametqStatus() const
+{ return d->mGametqStatus.value(); }
bool KGame::isRunning() const
-{ return d->mGameStatus.value() == Run; }
+{ return d->mGametqStatus.value() == Run; }
KGamePropertyHandler* KGame::dataHandler() const
{ return d->mProperties; }
@@ -772,7 +772,7 @@ KPlayer * KGame::playerInputFinished(KPlayer *player)
{
player->setTurn(false);
}
- setGameStatus(End);
+ setGametqStatus(End);
emit signalGameOver(gameOver,player,this);
}
else if (!player->asyncInput())
@@ -829,7 +829,7 @@ KPlayer *KGame::nextPlayer(KPlayer *last,bool exclusive)
return 0;
}
-void KGame::setGameStatus(int status)
+void KGame::setGametqStatus(int status)
{
kdDebug(11001) << k_funcinfo << ": GAMESTATUS CHANGED to" << status << endl;
if (status==(int)Run && playerCount()<minPlayers())
@@ -837,7 +837,7 @@ void KGame::setGameStatus(int status)
kdDebug(11001) << k_funcinfo << ": not enough players, pausing game\n" << endl;
status=Pause;
}
- d->mGameStatus = status;
+ d->mGametqStatus = status;
}
void KGame::networkTransmission(TQDataStream &stream, int msgid, TQ_UINT32 receiver, TQ_UINT32 sender, TQ_UINT32 /*clientID*/)
@@ -1244,7 +1244,7 @@ void KGame::Debug()
kdDebug(11001) << "------------------- KGAME -------------------------" << endl;
kdDebug(11001) << "this: " << this << endl;
kdDebug(11001) << "uniquePlayer " << d->mUniquePlayerNumber << endl;
- kdDebug(11001) << "gameStatus " << gameStatus() << endl;
+ kdDebug(11001) << "gameStatus " << gametqStatus() << endl;
kdDebug(11001) << "MaxPlayers : " << maxPlayers() << endl;
kdDebug(11001) << "NoOfPlayers : " << playerCount() << endl;
kdDebug(11001) << "NoOfInactive: " << d->mInactivePlayerList.count() << endl;
@@ -1264,7 +1264,7 @@ void KGame::slotServerDisconnected() // Client side
kdDebug(11001) << "======= SERVER DISCONNECT ======="<<endl;
kdDebug(11001) << "+++ (CLIENT)++++++++" << k_funcinfo << ": our GameID="<<gameId() << endl;
- int oldgamestatus=gameStatus();
+ int oldgamestatus=gametqStatus();
KPlayer *player;
KGamePlayerList removeList;
@@ -1326,7 +1326,7 @@ void KGame::slotClientDisconnected(TQ_UINT32 clientID,bool /*broken*/) // server
{
kdDebug(11001) << "++++(SERVER)+++++++" << k_funcinfo << " clientId=" << clientID << endl;
- int oldgamestatus=gameStatus();
+ int oldgamestatus=gametqStatus();
KPlayer *player;
KGamePlayerList removeList;
diff --git a/libtdegames/kgame/kgame.h b/libtdegames/kgame/kgame.h
index 7ad010fc..bf66dcb8 100644
--- a/libtdegames/kgame/kgame.h
+++ b/libtdegames/kgame/kgame.h
@@ -118,7 +118,7 @@ public:
* The KGame e.g. sets the status to Pause when you have
* less player than the minimum amount
*/
- enum GameStatus
+ enum GametqStatus
{
Init = 0,
Run = 1,
@@ -127,7 +127,7 @@ public:
Abort = 4,
SystemPause = 5,
Intro = 6,
- UserStatus = 7
+ UsertqStatus = 7
};
// Properties
@@ -387,14 +387,14 @@ public:
*
* @return game status
*/
- int gameStatus() const;
+ int gametqStatus() const;
/**
* sets the game status
*
* @param status the new status
*/
- void setGameStatus(int status);
+ void setGametqStatus(int status);
/**
* docu: see KPlayer
@@ -433,7 +433,7 @@ public:
* @param msg the message which will be send. See messages.txt for contents
* @param msgid an id for this message
* @param sender the id of the sender
- * @param group the group of the receivers
+ * @param group the group of the tqreceivers
* @return true if worked
*/
bool sendGroupMessage(const TQByteArray& msg, int msgid, TQ_UINT32 sender, const TQString& group);
diff --git a/libtdegames/kgame/kgamechat.cpp b/libtdegames/kgame/kgamechat.cpp
index c2469906..11f47f7b 100644
--- a/libtdegames/kgame/kgamechat.cpp
+++ b/libtdegames/kgame/kgamechat.cpp
@@ -92,7 +92,7 @@ void KGameChat::addMessage(int fromId, const TQString& text)
{
if (!d->mGame) {
kdWarning(11001) << "no KGame object has been set" << endl;
- addMessage(i18n("Player %1").arg(fromId), text);
+ addMessage(i18n("Player %1").tqarg(fromId), text);
} else {
KPlayer* p = d->mGame->findPlayer(fromId);
if (p) {
@@ -165,7 +165,7 @@ bool KGameChat::isToPlayerMessage(int id) const
return d->mSendId2PlayerId.contains(id); }
TQString KGameChat::sendToPlayerEntry(const TQString& name) const
-{ return i18n("Send to %1").arg(name); }
+{ return i18n("Send to %1").tqarg(name); }
int KGameChat::playerId(int id) const
{
@@ -211,7 +211,7 @@ void KGameChat::setFromPlayer(KPlayer* p)
removeSendingEntry(d->mToMyGroup);
}
d->mToMyGroup = nextId();
- addSendingEntry(i18n("Send to My Group (\"%1\")").arg(p->group()), d->mToMyGroup);
+ addSendingEntry(i18n("Send to My Group (\"%1\")").tqarg(p->group()), d->mToMyGroup);
}
d->mFromPlayer = p;
kdDebug(11001) << k_funcinfo << " player=" << p << endl;
diff --git a/libtdegames/kgame/kgameerror.cpp b/libtdegames/kgame/kgameerror.cpp
index 4ed64e0d..ef6145fb 100644
--- a/libtdegames/kgame/kgameerror.cpp
+++ b/libtdegames/kgame/kgameerror.cpp
@@ -60,7 +60,7 @@ TQString KGameError::errorText(int errorCode, TQDataStream& s)
TQ_INT32 cookie2;
s >> cookie1;
s >> cookie2;
- text = i18n("Cookie mismatch!\nExpected Cookie: %1\nReceived Cookie: %2").arg(cookie1).arg(cookie2);
+ text = i18n("Cookie mismatch!\nExpected Cookie: %1\nReceived Cookie: %2").tqarg(cookie1).tqarg(cookie2);
break;
}
case Version:
@@ -69,11 +69,11 @@ TQString KGameError::errorText(int errorCode, TQDataStream& s)
TQ_INT32 version2;
s >> version1;
s >> version2;
- text = i18n("KGame Version mismatch!\nExpected Version: %1\nReceived Version: %2\n").arg(version1).arg(version2);
+ text = i18n("KGame Version mismatch!\nExpected Version: %1\nReceived Version: %2\n").tqarg(version1).tqarg(version2);
break;
}
default:
- text = i18n("Unknown error code %1").arg(errorCode);
+ text = i18n("Unknown error code %1").tqarg(errorCode);
}
return text;
}
diff --git a/libtdegames/kgame/kgameproperty.h b/libtdegames/kgame/kgameproperty.h
index 0bb117b8..f02c4db0 100644
--- a/libtdegames/kgame/kgameproperty.h
+++ b/libtdegames/kgame/kgameproperty.h
@@ -51,7 +51,7 @@ public:
IdName=5,
//KGame
- IdGameStatus=6,
+ IdGametqStatus=6,
IdMaxPlayer=7,
IdMinPlayer=8,
diff --git a/libtdegames/kgame/kgamepropertyhandler.cpp b/libtdegames/kgame/kgamepropertyhandler.cpp
index 9ad43a69..405d433e 100644
--- a/libtdegames/kgame/kgamepropertyhandler.cpp
+++ b/libtdegames/kgame/kgamepropertyhandler.cpp
@@ -174,13 +174,13 @@ TQString KGamePropertyHandler::propertyName(int id) const
TQString s;
if (d->mIdDict.find(id)) {
if (d->mNameMap.contains(id)) {
- s = i18n("%1 (%2)").arg(d->mNameMap[id]).arg(id);
+ s = i18n("%1 (%2)").tqarg(d->mNameMap[id]).tqarg(id);
} else {
- s = i18n("Unnamed - ID: %1").arg(id);
+ s = i18n("Unnamed - ID: %1").tqarg(id);
}
} else {
// Should _never_ happen
- s = i18n("%1 unregistered").arg(id);
+ s = i18n("%1 unregistered").tqarg(id);
}
return s;
}
diff --git a/libtdegames/kgame/kmessageclient.cpp b/libtdegames/kgame/kmessageclient.cpp
index 056ca879..0233884a 100644
--- a/libtdegames/kgame/kmessageclient.cpp
+++ b/libtdegames/kgame/kmessageclient.cpp
@@ -132,7 +132,7 @@ TQ_UINT16 KMessageClient::peerPort () const
TQString KMessageClient::peerName () const
{
- return d->connection ? d->connection->peerName() : TQString::fromLatin1("localhost");
+ return d->connection ? d->connection->peerName() : TQString::tqfromLatin1("localhost");
}
// --------------------- Sending messages
@@ -228,9 +228,9 @@ void KMessageClient::processMessage (const TQByteArray &msg)
case KMessageServer::MSG_FORWARD:
{
TQ_UINT32 clientID;
- TQValueList <TQ_UINT32> receivers;
- in_stream >> clientID >> receivers;
- emit forwardReceived (in_buffer.readAll(), clientID, receivers);
+ TQValueList <TQ_UINT32> tqreceivers;
+ in_stream >> clientID >> tqreceivers;
+ emit forwardReceived (in_buffer.readAll(), clientID, tqreceivers);
}
break;
diff --git a/libtdegames/kgame/kmessageclient.h b/libtdegames/kgame/kmessageclient.h
index da15f16d..8a35234d 100644
--- a/libtdegames/kgame/kmessageclient.h
+++ b/libtdegames/kgame/kmessageclient.h
@@ -284,7 +284,7 @@ signals:
senderID contains the ID of the client that sent the broadcast message. You can
use this e.g. to send a reply message to only that client.
- receivers contains the list of the clients that got the message. (If this list
+ tqreceivers contains the list of the clients that got the message. (If this list
only contains one number, this will be your client ID, and it was exclusivly
sent to you.)
@@ -302,9 +302,9 @@ signals:
Then connect the broadcast signal to your slot that analyzes the message.
@param msg The message that has been sent to us
@param senderID The ID of the client which sent the message
- @param receivers All clients which receive this message
+ @param tqreceivers All clients which receive this message
*/
- void forwardReceived (const TQByteArray &msg, TQ_UINT32 senderID, const TQValueList <TQ_UINT32> &receivers);
+ void forwardReceived (const TQByteArray &msg, TQ_UINT32 senderID, const TQValueList <TQ_UINT32> &tqreceivers);
/**
This signal is emitted when the connection to the KMessageServer is broken.
diff --git a/libtdegames/kgame/kmessageio.cpp b/libtdegames/kgame/kmessageio.cpp
index b3dd1875..b35382b0 100644
--- a/libtdegames/kgame/kmessageio.cpp
+++ b/libtdegames/kgame/kmessageio.cpp
@@ -245,7 +245,7 @@ KMessageProcess::KMessageProcess(TQObject *parent, TQString file) : KMessageIO(p
mProcessName=file;
mProcess=new KProcess;
int id=0;
- *mProcess << mProcessName << TQString("%1").arg(id);
+ *mProcess << mProcessName << TQString("%1").tqarg(id);
kdDebug(11001) << "@@@KMessageProcess::Init:Id= " << id << endl;
kdDebug(11001) << "@@@KMessgeProcess::Init:Processname: " << mProcessName << endl;
connect(mProcess, TQT_SIGNAL(receivedStdout(KProcess *, char *, int )),
diff --git a/libtdegames/kgame/kmessageio.h b/libtdegames/kgame/kmessageio.h
index 69038df9..326476ff 100644
--- a/libtdegames/kgame/kmessageio.h
+++ b/libtdegames/kgame/kmessageio.h
@@ -123,7 +123,7 @@ public:
@since 3.2
@return "localhost" in the default implementation. Reimplemented in @ref KMessageSocket
*/
- virtual TQString peerName () const { return TQString::fromLatin1("localhost"); }
+ virtual TQString peerName () const { return TQString::tqfromLatin1("localhost"); }
signals:
diff --git a/libtdegames/kgame/kmessageserver.h b/libtdegames/kgame/kmessageserver.h
index 067ea3f9..9042fca2 100644
--- a/libtdegames/kgame/kmessageserver.h
+++ b/libtdegames/kgame/kmessageserver.h
@@ -83,7 +83,7 @@ class KMessageServerPrivate;
TQ_UINT32 clientID; // the ID of the client that sent the broadcast request
- TQByteArray << static_cast&lt;TQ_UINT32>( RETQ_FORWARD ) << client_list << raw_data
- TQValueList &lt;TQ_UINT32> client_list; // list of receivers
+ TQValueList &lt;TQ_UINT32> client_list; // list of tqreceivers
When the server receives this message, it sends the following message to
the clients in client_list:
diff --git a/libtdegames/kgame/messages.txt b/libtdegames/kgame/messages.txt
index 3a163790..c42d2d91 100644
--- a/libtdegames/kgame/messages.txt
+++ b/libtdegames/kgame/messages.txt
@@ -82,7 +82,7 @@ IdRemovePlayer Q_INT16 playerid
IdError Q_INT32 errorcode
QString errortext
-IdGameStatus Q_INT32 status
+IdGametqStatus Q_INT32 status
IdPlayerProperty Q_INT16 propertyId
user defined -> the property
diff --git a/libtdegames/kgamelcd.cpp b/libtdegames/kgamelcd.cpp
index f0e9d11c..cf079a15 100644
--- a/libtdegames/kgamelcd.cpp
+++ b/libtdegames/kgamelcd.cpp
@@ -20,7 +20,7 @@
#include "kgamelcd.h"
#include "kgamelcd.moc"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqtimer.h>
@@ -217,7 +217,7 @@ void KGameLCDList::init(const TQString &title)
top->setColStretch(1, 1);
_title = new TQLabel(title, this);
- _title->setAlignment(AlignCenter);
+ _title->tqsetAlignment(AlignCenter);
top->addMultiCellWidget(_title, 0, 0, 0, 1, AlignCenter);
}
@@ -232,11 +232,11 @@ void KGameLCDList::append(const TQString &leading, TQLCDNumber *lcd)
TQLabel *label = 0;
if ( !leading.isEmpty() ) {
label = new TQLabel(leading, this);
- static_cast<TQGridLayout *>(layout())->addWidget(label, i+1, 0);
+ static_cast<TQGridLayout *>(tqlayout())->addWidget(label, i+1, 0);
}
d->_leadings.push_back(label);
_lcds.push_back(lcd);
- static_cast<TQGridLayout *>(layout())->addWidget(lcd, i+1, 1);
+ static_cast<TQGridLayout *>(tqlayout())->addWidget(lcd, i+1, 1);
}
void KGameLCDList::clear()
diff --git a/libtdegames/kgamelcd.h b/libtdegames/kgamelcd.h
index f7bc69e6..6b84f012 100644
--- a/libtdegames/kgamelcd.h
+++ b/libtdegames/kgamelcd.h
@@ -184,7 +184,7 @@ private:
//-----------------------------------------------------------------------------
/**
- * This widget holds a list of @ref TQLCDNumber arranged in a vertical layout.
+ * This widget holds a list of @ref TQLCDNumber arranged in a vertical tqlayout.
* It also shows a label at the top of the list.
*
* @since 3.2
diff --git a/libtdegames/kgameprogress.cpp b/libtdegames/kgameprogress.cpp
index de32cd14..98876aa3 100644
--- a/libtdegames/kgameprogress.cpp
+++ b/libtdegames/kgameprogress.cpp
@@ -79,11 +79,11 @@ void KGameProgress::initialize()
void KGameProgress::paletteChange()
{
TQPalette p = kapp->palette();
- const TQColorGroup &colorGroup = p.active();
+ const TQColorGroup &tqcolorGroup = p.active();
if (!use_supplied_bar_color)
- bar_color = colorGroup.highlight();
- bar_text_color = colorGroup.highlightedText();
- text_color = colorGroup.text();
+ bar_color = tqcolorGroup.highlight();
+ bar_text_color = tqcolorGroup.highlightedText();
+ text_color = tqcolorGroup.text();
setPalette(p);
adjustStyle();
@@ -151,7 +151,7 @@ bool KGameProgress::textEnabled() const
return text_enabled;
}
-TQSize KGameProgress::sizeHint() const
+TQSize KGameProgress::tqsizeHint() const
{
TQSize s( size() );
@@ -164,9 +164,9 @@ TQSize KGameProgress::sizeHint() const
return s;
}
-TQSize KGameProgress::minimumSizeHint() const
+TQSize KGameProgress::tqminimumSizeHint() const
{
- return sizeHint();
+ return tqsizeHint();
}
TQSizePolicy KGameProgress::sizePolicy() const
@@ -196,13 +196,13 @@ int KGameProgress::recalcValue(int range)
void KGameProgress::valueChange()
{
- repaint(contentsRect(), FALSE);
+ tqrepaint(contentsRect(), FALSE);
emit percentageChanged(recalcValue(100));
}
void KGameProgress::rangeChange()
{
- repaint(contentsRect(), FALSE);
+ tqrepaint(contentsRect(), FALSE);
emit percentageChanged(recalcValue(100));
}
@@ -213,7 +213,7 @@ void KGameProgress::styleChange(TQStyle&)
void KGameProgress::adjustStyle()
{
- switch (tqstyle().styleHint(TQStyle::SH_GUIStyle)) {
+ switch (tqstyle().tqstyleHint(TQStyle::SH_GUIStyle)) {
case WindowsStyle:
setFrameStyle(TQFrame::WinPanel | TQFrame::Sunken);
break;
@@ -242,9 +242,9 @@ void KGameProgress::drawText(TQPainter *p)
// the current value and the maximum value respectively.
TQString s(format_);
- s.replace(TQRegExp(TQString::fromLatin1("%p")), TQString::number(recalcValue(100)));
- s.replace(TQRegExp(TQString::fromLatin1("%v")), TQString::number(value()));
- s.replace(TQRegExp(TQString::fromLatin1("%m")), TQString::number(maxValue()));
+ s.replace(TQRegExp(TQString::tqfromLatin1("%p")), TQString::number(recalcValue(100)));
+ s.replace(TQRegExp(TQString::tqfromLatin1("%v")), TQString::number(value()));
+ s.replace(TQRegExp(TQString::tqfromLatin1("%m")), TQString::number(maxValue()));
p->setPen(text_color);
TQFont font = p->font();
diff --git a/libtdegames/kgameprogress.h b/libtdegames/kgameprogress.h
index e4144b94..834b127c 100644
--- a/libtdegames/kgameprogress.h
+++ b/libtdegames/kgameprogress.h
@@ -162,11 +162,11 @@ public:
/**
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/**
*/
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
/**
*/
diff --git a/libtdegames/highscore/kexthighscore_item.h b/libtdegames/highscore/kexthighscore_item.h
index 8379433b..b32f32e7 100644
--- a/libtdegames/highscore/kexthighscore_item.h
+++ b/libtdegames/highscore/kexthighscore_item.h
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* Be sure to cast the value to the required type (for e.g. with uint).
* @param label the label corresponding to the item. If empty, the item
* is not shown.
* @param alignment the alignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,
- const TQString &label = TQString(), int alignment = TQt::AlignRight);
+ const TQString &label = TQString(), int tqalignment = TQt::AlignRight);
virtual ~Item();
@@ -114,9 +114,9 @@ class KDE_EXPORT Item
TQString label() const { return _label; }
/**
- * @return the alignment.
+ * @return the tqalignment.
*/
- int alignment() const { return _alignment; }
+ int tqalignment() const { return _tqalignment; }
/**
* Set default value.
@@ -149,7 +149,7 @@ class KDE_EXPORT Item
private:
TQVariant _default;
TQString _label;
- int _alignment;
+ int _tqalignment;
Format _format;
Special _special;
@@ -79,10 +79,10 @@ class KDE_EXPORT Item
* @param label the label corresponding to the item. If empty, the item
* is not shown.
- * @param alignment the alignment of the item.
+ * @param tqalignment the tqalignment of the item.
*/
Item(const TQVariant &def = TQVariant::Invalid,